/* backend.c generated by valac 0.24.0.16-c045, the Vala compiler
 * generated from backend.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Raul Gutierrez Segales <raul.gutierrez.segales@collabora.co.uk>
 *
 */

#include <glib.h>
#include <glib-object.h>
#include <gio/gio.h>
#include <libedataserver/libedataserver.h>
#include <stdlib.h>
#include <string.h>
#include <libebook/libebook.h>
#include <gee.h>
#include <libebook-contacts/libebook-contacts.h>
#include <folks/folks-eds.h>
#include <folks/folks.h>
#include <gobject/gvaluecollector.h>


#define EDS_TEST_TYPE_BACKEND (eds_test_backend_get_type ())
#define EDS_TEST_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), EDS_TEST_TYPE_BACKEND, EdsTestBackend))
#define EDS_TEST_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), EDS_TEST_TYPE_BACKEND, EdsTestBackendClass))
#define EDS_TEST_IS_BACKEND(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), EDS_TEST_TYPE_BACKEND))
#define EDS_TEST_IS_BACKEND_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), EDS_TEST_TYPE_BACKEND))
#define EDS_TEST_BACKEND_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), EDS_TEST_TYPE_BACKEND, EdsTestBackendClass))

typedef struct _EdsTestBackend EdsTestBackend;
typedef struct _EdsTestBackendClass EdsTestBackendClass;
typedef struct _EdsTestBackendPrivate EdsTestBackendPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _eds_test_backend_unref0(var) ((var == NULL) ? NULL : (var = (eds_test_backend_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _EdsTestBackendUpdateContactData EdsTestBackendUpdateContactData;
typedef struct _EdsTestBackendRemoveContactData EdsTestBackendRemoveContactData;
typedef struct _Block1Data Block1Data;
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
typedef struct _Block2Data Block2Data;
typedef struct _EdsTestBackendPrepareSourceAsyncData EdsTestBackendPrepareSourceAsyncData;
#define __g_slist_free__g_free0_0(var) ((var == NULL) ? NULL : (var = (_g_slist_free__g_free0_ (var), NULL)))
#define __g_slist_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_slist_free__g_object_unref0_ (var), NULL)))
typedef struct _EdsTestBackendCommitContactsToAddressbookData EdsTestBackendCommitContactsToAddressbookData;
#define __vala_GValue_free0(var) ((var == NULL) ? NULL : (var = (_vala_GValue_free (var), NULL)))
#define __vala_EContactPhoto_free0(var) ((var == NULL) ? NULL : (var = (_vala_EContactPhoto_free (var), NULL)))
#define __vala_EContactName_free0(var) ((var == NULL) ? NULL : (var = (_vala_EContactName_free (var), NULL)))
#define __vala_EContactAddress_free0(var) ((var == NULL) ? NULL : (var = (_vala_EContactAddress_free (var), NULL)))
typedef struct _EdsTestParamSpecBackend EdsTestParamSpecBackend;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

typedef enum  {
	EDS_TEST_BACKEND_SETUP_ERROR_FETCH_SOURCE_GROUP_FAILED,
	EDS_TEST_BACKEND_SETUP_ERROR_OPENING_FAILED,
	EDS_TEST_BACKEND_SETUP_ERROR_ADD_CONTACT_FAILED,
	EDS_TEST_BACKEND_SETUP_ERROR_ADD_TO_SOURCE_GROUP_FAILED
} EdsTestBackendSetupError;
#define EDS_TEST_BACKEND_SETUP_ERROR eds_test_backend_setup_error_quark ()
struct _EdsTestBackend {
	GTypeInstance parent_instance;
	volatile int ref_count;
	EdsTestBackendPrivate * priv;
};

struct _EdsTestBackendClass {
	GTypeClass parent_class;
	void (*finalize) (EdsTestBackend *self);
};

struct _EdsTestBackendPrivate {
	gchar* _addressbook_name;
	EBookClient* _addressbook;
	gchar** _e_contacts;
	gint _e_contacts_length1;
	gint __e_contacts_size_;
	GList* _contacts;
	ESourceRegistry* _source_registry;
	ESource* _source;
	GFile* _source_file;
};

struct _EdsTestBackendUpdateContactData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	EdsTestBackend* self;
	gint contact_pos;
	GeeHashMap* updated_data;
	gchar* uid;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gint _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	EContact* contact;
	EBookClient* _tmp4_;
	const gchar* _tmp5_;
	EContact* _tmp6_;
	EContact* _tmp7_;
	GeeHashMap* _tmp8_;
	EBookClient* _tmp9_;
	EContact* _tmp10_;
	GError* e;
	GError * _inner_error_;
};

struct _EdsTestBackendRemoveContactData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	EdsTestBackend* self;
	gint contact_pos;
	gchar* uid;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gint _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	EContact* contact;
	EBookClient* _tmp4_;
	const gchar* _tmp5_;
	EContact* _tmp6_;
	EBookClient* _tmp7_;
	EContact* _tmp8_;
	GError* e;
	GError * _inner_error_;
};

struct _Block1Data {
	int _ref_count_;
	EdsTestBackend* self;
	GMainLoop* mainloop;
};

struct _Block2Data {
	int _ref_count_;
	EdsTestBackend* self;
	gpointer _async_data_;
};

struct _EdsTestBackendPrepareSourceAsyncData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	EdsTestBackend* self;
	gboolean is_default;
	Block2Data* _data2_;
	gchar* source_file_name;
	const gchar* _tmp0_;
	gchar* _tmp1_;
	GFile* config_dir;
	const gchar* _tmp2_;
	GFile* _tmp3_;
	GFile* source_file;
	GFile* _tmp4_;
	GFile* _tmp5_;
	GFile* _tmp6_;
	GFile* _tmp7_;
	GFile* _tmp8_;
	const gchar* _tmp9_;
	GFile* _tmp10_;
	GFile* _tmp11_;
	gchar* source_file_content;
	const gchar* _tmp12_;
	gchar* _tmp13_;
	ESourceRegistry* source_registry;
	ESourceRegistry* _tmp14_;
	ESourceRegistry* _tmp15_;
	ESourceRegistry* _tmp16_;
	gulong signal_id;
	ESourceRegistry* _tmp17_;
	gulong _tmp18_;
	GFile* _tmp19_;
	const gchar* _tmp20_;
	guint8* _tmp21_;
	gint _tmp21__length1;
	guint8* _tmp22_;
	gint _tmp22__length1;
	ESourceRegistry* _tmp23_;
	const gchar* _tmp24_;
	ESource* _tmp25_;
	ESource* _tmp26_;
	ESource* _tmp27_;
	ESourceRegistry* _tmp28_;
	gulong _tmp29_;
	GFile* _tmp30_;
	GFile* _tmp31_;
	gboolean _tmp32_;
	GError * _inner_error_;
};

struct _EdsTestBackendCommitContactsToAddressbookData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	EdsTestBackend* self;
	GSList* contacts;
	GList* _tmp0_;
	GList* c_collection;
	GList* c_it;
	GeeHashMap* _tmp1_;
	GeeHashMap* c;
	EContact* contact;
	EContact* _tmp2_;
	EContact* _tmp3_;
	GeeHashMap* _tmp4_;
	EContact* _tmp5_;
	EContact* _tmp6_;
	GSList* uids;
	EBookClient* _tmp7_;
	GSList* _tmp8_;
	GSList* _tmp9_;
	GSList* uid_collection;
	GSList* uid_it;
	const gchar* uid;
	gchar** _tmp10_;
	gint _tmp10__length1;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	GError* e;
	GError* _tmp13_;
	const gchar* _tmp14_;
	GError * _inner_error_;
};

struct _EdsTestParamSpecBackend {
	GParamSpec parent_instance;
};


static gpointer eds_test_backend_parent_class = NULL;

void e_source_registry_new (GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
ESourceRegistry* e_source_registry_new_finish (GAsyncResult* _res_, GError** error);
GQuark eds_test_backend_setup_error_quark (void);
gpointer eds_test_backend_ref (gpointer instance);
void eds_test_backend_unref (gpointer instance);
GParamSpec* eds_test_param_spec_backend (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void eds_test_value_set_backend (GValue* value, gpointer v_object);
void eds_test_value_take_backend (GValue* value, gpointer v_object);
gpointer eds_test_value_get_backend (const GValue* value);
GType eds_test_backend_get_type (void) G_GNUC_CONST;
#define EDS_TEST_BACKEND_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), EDS_TEST_TYPE_BACKEND, EdsTestBackendPrivate))
enum  {
	EDS_TEST_BACKEND_DUMMY_PROPERTY
};
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
EdsTestBackend* eds_test_backend_new (void);
EdsTestBackend* eds_test_backend_construct (GType object_type);
void eds_test_backend_add_contact (EdsTestBackend* self, GeeHashMap* c);
static void eds_test_backend_update_contact_data_free (gpointer _data);
void eds_test_backend_update_contact (EdsTestBackend* self, gint contact_pos, GeeHashMap* updated_data, GAsyncReadyCallback _callback_, gpointer _user_data_);
void eds_test_backend_update_contact_finish (EdsTestBackend* self, GAsyncResult* _res_);
static gboolean eds_test_backend_update_contact_co (EdsTestBackendUpdateContactData* _data_);
static void eds_test_backend_update_contact_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _eds_test_backend_set_contact_fields (EdsTestBackend* self, EContact* contact, GeeHashMap* c);
static void eds_test_backend_remove_contact_data_free (gpointer _data);
void eds_test_backend_remove_contact (EdsTestBackend* self, gint contact_pos, GAsyncReadyCallback _callback_, gpointer _user_data_);
void eds_test_backend_remove_contact_finish (EdsTestBackend* self, GAsyncResult* _res_);
static gboolean eds_test_backend_remove_contact_co (EdsTestBackendRemoveContactData* _data_);
static void eds_test_backend_remove_contact_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
void eds_test_backend_reset (EdsTestBackend* self);
void eds_test_backend_set_up (EdsTestBackend* self, gboolean source_is_default, const gchar* name);
static void _eds_test_backend_prepare_source (EdsTestBackend* self, gboolean is_default);
void eds_test_backend_set_as_default (EdsTestBackend* self);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void _eds_test_backend_prepare_source_async (EdsTestBackend* self, gboolean is_default, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _eds_test_backend_prepare_source_finish (EdsTestBackend* self, GAsyncResult* _res_, GError** error);
static void __lambda4_ (Block1Data* _data1_, GObject* obj, GAsyncResult* async_res);
static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void _eds_test_backend_prepare_source_async_data_free (gpointer _data);
static gboolean _eds_test_backend_prepare_source_async_co (EdsTestBackendPrepareSourceAsyncData* _data_);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void _eds_test_backend_prepare_source_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void __lambda3_ (Block2Data* _data2_, ESourceRegistry* r, ESource* s);
static void ___lambda3__e_source_registry_source_added (ESourceRegistry* _sender, ESource* source, gpointer self);
static void eds_test_backend_commit_contacts_to_addressbook_data_free (gpointer _data);
void eds_test_backend_commit_contacts_to_addressbook (EdsTestBackend* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void eds_test_backend_commit_contacts_to_addressbook_finish (EdsTestBackend* self, GAsyncResult* _res_);
static gboolean eds_test_backend_commit_contacts_to_addressbook_co (EdsTestBackendCommitContactsToAddressbookData* _data_);
static void eds_test_backend_commit_contacts_to_addressbook_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void _g_free0_ (gpointer var);
static void _g_slist_free__g_free0_ (GSList* self);
static void _vala_array_add1 (gchar*** array, int* length, int* size, gchar* value);
static void _g_slist_free__g_object_unref0_ (GSList* self);
static void _vala_GValue_free (GValue* self);
static void _vala_EContactPhoto_free (EContactPhoto* self);
static void _vala_EContactName_free (EContactName* self);
static GeeHashMap* _eds_test_backend_parse_im_addrs (EdsTestBackend* self, const gchar* addr_str);
static void _vala_EContactAddress_free (EContactAddress* self);
void eds_test_backend_tear_down (EdsTestBackend* self);
const gchar* eds_test_backend_get_address_book_uid (EdsTestBackend* self);
static void eds_test_backend_finalize (EdsTestBackend* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


GQuark eds_test_backend_setup_error_quark (void) {
	return g_quark_from_static_string ("eds_test_backend_setup_error-quark");
}


static void _g_object_unref0_ (gpointer var) {
#line 43 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 332 "backend.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 43 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 43 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_list_free (self);
#line 341 "backend.c"
}


EdsTestBackend* eds_test_backend_construct (GType object_type) {
	EdsTestBackend* self = NULL;
	gchar** _tmp0_ = NULL;
#line 53 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self = (EdsTestBackend*) g_type_create_instance (object_type);
#line 55 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	__g_list_free__g_object_unref0_0 (self->priv->_contacts);
#line 55 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_contacts = NULL;
#line 56 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = g_new0 (gchar*, 0 + 1);
#line 56 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_e_contacts = (_vala_array_free (self->priv->_e_contacts, self->priv->_e_contacts_length1, (GDestroyNotify) g_free), NULL);
#line 56 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_e_contacts = _tmp0_;
#line 56 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_e_contacts_length1 = 0;
#line 56 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->__e_contacts_size_ = self->priv->_e_contacts_length1;
#line 53 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return self;
#line 366 "backend.c"
}


EdsTestBackend* eds_test_backend_new (void) {
#line 53 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return eds_test_backend_construct (EDS_TEST_TYPE_BACKEND);
#line 373 "backend.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 61 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return self ? g_object_ref (self) : NULL;
#line 380 "backend.c"
}


void eds_test_backend_add_contact (EdsTestBackend* self, GeeHashMap* c) {
	GeeHashMap* _tmp0_ = NULL;
	GeeHashMap* _tmp1_ = NULL;
#line 59 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (self != NULL);
#line 59 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (c != NULL);
#line 61 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = c;
#line 61 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 61 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_contacts = g_list_prepend (self->priv->_contacts, _tmp1_);
#line 59 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (c);
#line 399 "backend.c"
}


static void eds_test_backend_update_contact_data_free (gpointer _data) {
	EdsTestBackendUpdateContactData* _data_;
	_data_ = _data;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->updated_data);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_eds_test_backend_unref0 (_data_->self);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_slice_free (EdsTestBackendUpdateContactData, _data_);
#line 412 "backend.c"
}


static gpointer _eds_test_backend_ref0 (gpointer self) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return self ? eds_test_backend_ref (self) : NULL;
#line 419 "backend.c"
}


void eds_test_backend_update_contact (EdsTestBackend* self, gint contact_pos, GeeHashMap* updated_data, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	EdsTestBackendUpdateContactData* _data_;
	EdsTestBackend* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = g_slice_new0 (EdsTestBackendUpdateContactData);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, eds_test_backend_update_contact);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, eds_test_backend_update_contact_data_free);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = _eds_test_backend_ref0 (self);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->self = _tmp0_;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp1_ = contact_pos;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->contact_pos = _tmp1_;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->updated_data);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->updated_data = updated_data;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	eds_test_backend_update_contact_co (_data_);
#line 447 "backend.c"
}


void eds_test_backend_update_contact_finish (EdsTestBackend* self, GAsyncResult* _res_) {
	EdsTestBackendUpdateContactData* _data_;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 455 "backend.c"
}


static void eds_test_backend_update_contact_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	EdsTestBackendUpdateContactData* _data_;
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = _user_data_;
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_source_object_ = source_object;
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_res_ = _res_;
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	eds_test_backend_update_contact_co (_data_);
#line 469 "backend.c"
}


static gboolean eds_test_backend_update_contact_co (EdsTestBackendUpdateContactData* _data_) {
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	switch (_data_->_state_) {
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 0:
#line 478 "backend.c"
		goto _state_0;
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 1:
#line 482 "backend.c"
		goto _state_1;
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 2:
#line 486 "backend.c"
		goto _state_2;
		default:
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_assert_not_reached ();
#line 491 "backend.c"
	}
	_state_0:
#line 67 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0_ = NULL;
#line 67 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0__length1 = 0;
#line 67 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0_ = _data_->self->priv->_e_contacts;
#line 67 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0__length1 = _data_->self->priv->_e_contacts_length1;
#line 67 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp1_ = 0;
#line 67 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp1_ = _data_->contact_pos;
#line 67 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp2_ = NULL;
#line 67 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp2_ = _data_->_tmp0_[_data_->_tmp1_];
#line 67 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp3_ = NULL;
#line 67 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp3_ = g_strdup (_data_->_tmp2_);
#line 67 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->uid = _data_->_tmp3_;
#line 516 "backend.c"
	{
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp4_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp4_ = _data_->self->priv->_addressbook;
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp5_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp5_ = _data_->uid;
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp6_ = NULL;
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_state_ = 1;
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e_book_client_get_contact (_data_->_tmp4_, _data_->_tmp5_, NULL, eds_test_backend_update_contact_ready, _data_);
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return FALSE;
#line 534 "backend.c"
		_state_1:
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e_book_client_get_contact_finish (_data_->_tmp4_, _data_->_res_, &_data_->_tmp6_, &_data_->_inner_error_);
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_data_->contact);
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->contact = _data_->_tmp6_;
#line 71 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		if (_data_->_inner_error_ != NULL) {
#line 544 "backend.c"
			goto __catch0_g_error;
		}
#line 72 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp7_ = NULL;
#line 72 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp7_ = _data_->contact;
#line 72 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp8_ = NULL;
#line 72 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp8_ = _data_->updated_data;
#line 72 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_eds_test_backend_set_contact_fields (_data_->self, _data_->_tmp7_, _data_->_tmp8_);
#line 73 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp9_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp9_ = _data_->self->priv->_addressbook;
#line 73 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp10_ = NULL;
#line 73 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp10_ = _data_->contact;
#line 73 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_state_ = 2;
#line 73 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e_book_client_modify_contact (_data_->_tmp9_, _data_->_tmp10_, NULL, eds_test_backend_update_contact_ready, _data_);
#line 73 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return FALSE;
#line 571 "backend.c"
		_state_2:
#line 73 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e_book_client_modify_contact_finish (_data_->_tmp9_, _data_->_res_, &_data_->_inner_error_);
#line 73 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		if (_data_->_inner_error_ != NULL) {
#line 577 "backend.c"
			goto __catch0_g_error;
		}
	}
	goto __finally0;
	__catch0_g_error:
	{
#line 69 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->e = _data_->_inner_error_;
#line 69 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_inner_error_ = NULL;
#line 77 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_warning ("backend.vala:77: Couldn't update contact\n");
#line 69 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_error_free0 (_data_->e);
#line 592 "backend.c"
	}
	__finally0:
#line 69 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_data_->_inner_error_ != NULL) {
#line 69 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_data_->contact);
#line 69 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_free0 (_data_->uid);
#line 69 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_data_->updated_data);
#line 69 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 69 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_clear_error (&_data_->_inner_error_);
#line 69 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return FALSE;
#line 609 "backend.c"
	}
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->contact);
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_free0 (_data_->uid);
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->updated_data);
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_data_->_state_ == 0) {
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 621 "backend.c"
	} else {
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 625 "backend.c"
	}
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_object_unref (_data_->_async_result);
#line 64 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return FALSE;
#line 631 "backend.c"
}


static void eds_test_backend_remove_contact_data_free (gpointer _data) {
	EdsTestBackendRemoveContactData* _data_;
	_data_ = _data;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_eds_test_backend_unref0 (_data_->self);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_slice_free (EdsTestBackendRemoveContactData, _data_);
#line 642 "backend.c"
}


void eds_test_backend_remove_contact (EdsTestBackend* self, gint contact_pos, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	EdsTestBackendRemoveContactData* _data_;
	EdsTestBackend* _tmp0_ = NULL;
	gint _tmp1_ = 0;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = g_slice_new0 (EdsTestBackendRemoveContactData);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, eds_test_backend_remove_contact);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, eds_test_backend_remove_contact_data_free);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = _eds_test_backend_ref0 (self);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->self = _tmp0_;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp1_ = contact_pos;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->contact_pos = _tmp1_;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	eds_test_backend_remove_contact_co (_data_);
#line 666 "backend.c"
}


void eds_test_backend_remove_contact_finish (EdsTestBackend* self, GAsyncResult* _res_) {
	EdsTestBackendRemoveContactData* _data_;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 674 "backend.c"
}


static void eds_test_backend_remove_contact_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	EdsTestBackendRemoveContactData* _data_;
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = _user_data_;
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_source_object_ = source_object;
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_res_ = _res_;
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	eds_test_backend_remove_contact_co (_data_);
#line 688 "backend.c"
}


static gboolean eds_test_backend_remove_contact_co (EdsTestBackendRemoveContactData* _data_) {
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	switch (_data_->_state_) {
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 0:
#line 697 "backend.c"
		goto _state_0;
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 1:
#line 701 "backend.c"
		goto _state_1;
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 2:
#line 705 "backend.c"
		goto _state_2;
		default:
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_assert_not_reached ();
#line 710 "backend.c"
	}
	_state_0:
#line 83 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0_ = NULL;
#line 83 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0__length1 = 0;
#line 83 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0_ = _data_->self->priv->_e_contacts;
#line 83 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0__length1 = _data_->self->priv->_e_contacts_length1;
#line 83 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp1_ = 0;
#line 83 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp1_ = _data_->contact_pos;
#line 83 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp2_ = NULL;
#line 83 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp2_ = _data_->_tmp0_[_data_->_tmp1_];
#line 83 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp3_ = NULL;
#line 83 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp3_ = g_strdup (_data_->_tmp2_);
#line 83 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->uid = _data_->_tmp3_;
#line 735 "backend.c"
	{
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp4_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp4_ = _data_->self->priv->_addressbook;
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp5_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp5_ = _data_->uid;
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp6_ = NULL;
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_state_ = 1;
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e_book_client_get_contact (_data_->_tmp4_, _data_->_tmp5_, NULL, eds_test_backend_remove_contact_ready, _data_);
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return FALSE;
#line 753 "backend.c"
		_state_1:
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e_book_client_get_contact_finish (_data_->_tmp4_, _data_->_res_, &_data_->_tmp6_, &_data_->_inner_error_);
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_data_->contact);
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->contact = _data_->_tmp6_;
#line 87 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		if (_data_->_inner_error_ != NULL) {
#line 763 "backend.c"
			goto __catch1_g_error;
		}
#line 88 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp7_ = NULL;
#line 88 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp7_ = _data_->self->priv->_addressbook;
#line 88 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp8_ = NULL;
#line 88 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp8_ = _data_->contact;
#line 88 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_state_ = 2;
#line 88 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e_book_client_remove_contact (_data_->_tmp7_, _data_->_tmp8_, NULL, eds_test_backend_remove_contact_ready, _data_);
#line 88 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return FALSE;
#line 780 "backend.c"
		_state_2:
#line 88 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e_book_client_remove_contact_finish (_data_->_tmp7_, _data_->_res_, &_data_->_inner_error_);
#line 88 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		if (_data_->_inner_error_ != NULL) {
#line 786 "backend.c"
			goto __catch1_g_error;
		}
	}
	goto __finally1;
	__catch1_g_error:
	{
#line 85 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->e = _data_->_inner_error_;
#line 85 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_inner_error_ = NULL;
#line 92 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_warning ("backend.vala:92: Couldn't remove contact\n");
#line 85 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_error_free0 (_data_->e);
#line 801 "backend.c"
	}
	__finally1:
#line 85 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_data_->_inner_error_ != NULL) {
#line 85 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_data_->contact);
#line 85 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_free0 (_data_->uid);
#line 85 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 85 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_clear_error (&_data_->_inner_error_);
#line 85 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return FALSE;
#line 816 "backend.c"
	}
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->contact);
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_free0 (_data_->uid);
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_data_->_state_ == 0) {
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 826 "backend.c"
	} else {
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 830 "backend.c"
	}
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_object_unref (_data_->_async_result);
#line 81 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return FALSE;
#line 836 "backend.c"
}


void eds_test_backend_reset (EdsTestBackend* self) {
	gchar** _tmp0_ = NULL;
#line 96 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (self != NULL);
#line 98 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	__g_list_free__g_object_unref0_0 (self->priv->_contacts);
#line 98 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_contacts = NULL;
#line 99 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = g_new0 (gchar*, 0 + 1);
#line 99 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_e_contacts = (_vala_array_free (self->priv->_e_contacts, self->priv->_e_contacts_length1, (GDestroyNotify) g_free), NULL);
#line 99 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_e_contacts = _tmp0_;
#line 99 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_e_contacts_length1 = 0;
#line 99 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->__e_contacts_size_ = self->priv->_e_contacts_length1;
#line 858 "backend.c"
}


void eds_test_backend_set_up (EdsTestBackend* self, gboolean source_is_default, const gchar* name) {
	GError * _inner_error_ = NULL;
#line 103 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (self != NULL);
#line 103 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (name != NULL);
#line 868 "backend.c"
	{
		const gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gboolean _tmp2_ = FALSE;
		EBookClient* _tmp3_ = NULL;
		ESource* _tmp4_ = NULL;
		EBookClient* _tmp5_ = NULL;
		EBookClient* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
#line 108 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp0_ = name;
#line 108 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp1_ = g_strdup (_tmp0_);
#line 108 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_free0 (self->priv->_addressbook_name);
#line 108 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		self->priv->_addressbook_name = _tmp1_;
#line 110 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp2_ = source_is_default;
#line 110 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_eds_test_backend_prepare_source (self, _tmp2_);
#line 111 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp4_ = self->priv->_source;
#line 111 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp5_ = e_book_client_connect_sync (_tmp4_, NULL, &_inner_error_);
#line 111 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp3_ = _tmp5_;
#line 111 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		if (_inner_error_ != NULL) {
#line 898 "backend.c"
			goto __catch2_g_error;
		}
#line 111 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp6_ = _tmp3_;
#line 111 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp3_ = NULL;
#line 111 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (self->priv->_addressbook);
#line 111 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		self->priv->_addressbook = _tmp6_;
#line 112 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp7_ = self->priv->_addressbook_name;
#line 112 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_setenv ("FOLKS_BACKEND_EDS_USE_ADDRESS_BOOKS", _tmp7_, TRUE);
#line 105 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_tmp3_);
#line 915 "backend.c"
	}
	goto __finally2;
	__catch2_g_error:
	{
		GError* e = NULL;
		GError* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
#line 105 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e = _inner_error_;
#line 105 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_inner_error_ = NULL;
#line 117 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp8_ = e;
#line 117 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp9_ = _tmp8_->message;
#line 117 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_warning ("backend.vala:117: Unable to create test data: %s\n", _tmp9_);
#line 105 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_error_free0 (e);
#line 935 "backend.c"
	}
	__finally2:
#line 105 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_inner_error_ != NULL) {
#line 105 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 105 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_clear_error (&_inner_error_);
#line 105 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return;
#line 946 "backend.c"
	}
}


void eds_test_backend_set_as_default (EdsTestBackend* self) {
	ESourceRegistry* _tmp0_ = NULL;
	ESource* _tmp1_ = NULL;
#line 121 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (self != NULL);
#line 123 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = self->priv->_source_registry;
#line 123 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp1_ = self->priv->_source;
#line 123 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	e_source_registry_set_default_address_book (_tmp0_, _tmp1_);
#line 962 "backend.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return _data1_;
#line 971 "backend.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 980 "backend.c"
		EdsTestBackend* self;
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		self = _data1_->self;
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_main_loop_unref0 (_data1_->mainloop);
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_eds_test_backend_unref0 (self);
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_slice_free (Block1Data, _data1_);
#line 990 "backend.c"
	}
}


static void __lambda4_ (Block1Data* _data1_, GObject* obj, GAsyncResult* async_res) {
	EdsTestBackend* self;
	GError * _inner_error_ = NULL;
#line 130 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self = _data1_->self;
#line 130 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (async_res != NULL);
#line 1002 "backend.c"
	{
		GAsyncResult* _tmp0_ = NULL;
#line 134 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp0_ = async_res;
#line 134 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_eds_test_backend_prepare_source_finish (self, _tmp0_, &_inner_error_);
#line 134 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		if (_inner_error_ != NULL) {
#line 1011 "backend.c"
			goto __catch3_g_error;
		}
#line 135 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_main_loop_quit (_data1_->mainloop);
#line 1016 "backend.c"
	}
	goto __finally3;
	__catch3_g_error:
	{
		GError* e = NULL;
		GError* _tmp1_ = NULL;
		const gchar* _tmp2_ = NULL;
#line 132 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e = _inner_error_;
#line 132 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_inner_error_ = NULL;
#line 139 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp1_ = e;
#line 139 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp2_ = _tmp1_->message;
#line 139 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_critical ("backend.vala:139: %s", _tmp2_);
#line 132 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_error_free0 (e);
#line 1036 "backend.c"
	}
	__finally3:
#line 132 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_inner_error_ != NULL) {
#line 132 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 132 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_clear_error (&_inner_error_);
#line 132 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return;
#line 1047 "backend.c"
	}
}


static void ___lambda4__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 130 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	__lambda4_ (self, source_object, res);
#line 130 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	block1_data_unref (self);
#line 1057 "backend.c"
}


static void _eds_test_backend_prepare_source (EdsTestBackend* self, gboolean is_default) {
	Block1Data* _data1_;
	GMainLoop* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (self != NULL);
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data1_->_ref_count_ = 1;
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data1_->self = eds_test_backend_ref (self);
#line 128 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 128 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data1_->mainloop = _tmp0_;
#line 130 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp1_ = is_default;
#line 130 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_eds_test_backend_prepare_source_async (self, _tmp1_, ___lambda4__gasync_ready_callback, block1_data_ref (_data1_));
#line 143 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_main_loop_run (_data1_->mainloop);
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	block1_data_unref (_data1_);
#line 126 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data1_ = NULL;
#line 1087 "backend.c"
}


static void _eds_test_backend_prepare_source_async_data_free (gpointer _data) {
	EdsTestBackendPrepareSourceAsyncData* _data_;
	_data_ = _data;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_eds_test_backend_unref0 (_data_->self);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_slice_free (EdsTestBackendPrepareSourceAsyncData, _data_);
#line 1098 "backend.c"
}


static void _eds_test_backend_prepare_source_async (EdsTestBackend* self, gboolean is_default, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	EdsTestBackendPrepareSourceAsyncData* _data_;
	EdsTestBackend* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = g_slice_new0 (EdsTestBackendPrepareSourceAsyncData);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, _eds_test_backend_prepare_source_async);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _eds_test_backend_prepare_source_async_data_free);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = _eds_test_backend_ref0 (self);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->self = _tmp0_;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp1_ = is_default;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->is_default = _tmp1_;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_eds_test_backend_prepare_source_async_co (_data_);
#line 1122 "backend.c"
}


static void _eds_test_backend_prepare_source_finish (EdsTestBackend* self, GAsyncResult* _res_, GError** error) {
	EdsTestBackendPrepareSourceAsyncData* _data_;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return;
#line 1132 "backend.c"
	}
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1136 "backend.c"
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return _data2_;
#line 1145 "backend.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1154 "backend.c"
		EdsTestBackend* self;
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		self = _data2_->self;
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_eds_test_backend_unref0 (self);
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_slice_free (Block2Data, _data2_);
#line 1162 "backend.c"
	}
}


static void _eds_test_backend_prepare_source_async_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	EdsTestBackendPrepareSourceAsyncData* _data_;
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = _user_data_;
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_source_object_ = source_object;
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_res_ = _res_;
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_eds_test_backend_prepare_source_async_co (_data_);
#line 1177 "backend.c"
}


static void __lambda3_ (Block2Data* _data2_, ESourceRegistry* r, ESource* s) {
	EdsTestBackend* self;
	ESource* _tmp0_ = NULL;
	ESource* _tmp1_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self = _data2_->self;
#line 166 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (r != NULL);
#line 166 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (s != NULL);
#line 168 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = s;
#line 168 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 168 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (self->priv->_source);
#line 168 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_source = _tmp1_;
#line 169 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_eds_test_backend_prepare_source_async_co (_data2_->_async_data_);
#line 1201 "backend.c"
}


static void ___lambda3__e_source_registry_source_added (ESourceRegistry* _sender, ESource* source, gpointer self) {
#line 166 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	__lambda3_ (self, _sender, source);
#line 1208 "backend.c"
}


static guint8* string_get_data (const gchar* self, int* result_length1) {
	guint8* result;
	guint8* res = NULL;
	gint res_length1 = 0;
	gint _res_size_ = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	gint _tmp2_ = 0;
	guint8* _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	guint8* _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 1296 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1297 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	res = (guint8*) self;
#line 1297 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	res_length1 = -1;
#line 1297 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_res_size_ = res_length1;
#line 1298 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1298 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1298 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	res_length1 = (gint) _tmp1_;
#line 1298 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp2_ = res_length1;
#line 1299 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp3_ = res;
#line 1299 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp3__length1 = res_length1;
#line 1299 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp4_ = _tmp3_;
#line 1299 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp4__length1 = _tmp3__length1;
#line 1299 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	if (result_length1) {
#line 1299 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		*result_length1 = _tmp4__length1;
#line 1252 "backend.c"
	}
#line 1299 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	result = _tmp4_;
#line 1299 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 1258 "backend.c"
}


static gboolean _eds_test_backend_prepare_source_async_co (EdsTestBackendPrepareSourceAsyncData* _data_) {
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	switch (_data_->_state_) {
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 0:
#line 1267 "backend.c"
		goto _state_0;
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 1:
#line 1271 "backend.c"
		goto _state_1;
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 2:
#line 1275 "backend.c"
		goto _state_2;
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 3:
#line 1279 "backend.c"
		goto _state_3;
		default:
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_assert_not_reached ();
#line 1284 "backend.c"
	}
	_state_0:
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_data2_ = g_slice_new0 (Block2Data);
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_data2_->_ref_count_ = 1;
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_data2_->self = eds_test_backend_ref (_data_->self);
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_data2_->_async_data_ = _data_;
#line 149 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0_ = _data_->self->priv->_addressbook_name;
#line 149 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp1_ = NULL;
#line 149 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp1_ = g_strconcat (_data_->_tmp0_, ".source", NULL);
#line 149 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->source_file_name = _data_->_tmp1_;
#line 151 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp2_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp2_ = g_get_user_config_dir ();
#line 151 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp3_ = NULL;
#line 151 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp3_ = g_file_new_for_path (_data_->_tmp2_);
#line 151 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->config_dir = _data_->_tmp3_;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp4_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp4_ = _data_->config_dir;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp5_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp5_ = g_file_get_child (_data_->_tmp4_, "evolution");
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp6_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp6_ = _data_->_tmp5_;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp7_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp7_ = g_file_get_child (_data_->_tmp6_, "sources");
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp8_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp9_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp9_ = _data_->source_file_name;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp10_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp10_ = g_file_get_child (_data_->_tmp8_, _data_->_tmp9_);
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp11_ = NULL;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp11_ = _data_->_tmp10_;
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->_tmp8_);
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->_tmp6_);
#line 152 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->source_file = _data_->_tmp11_;
#line 155 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp12_ = NULL;
#line 155 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp12_ = _data_->self->priv->_addressbook_name;
#line 155 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp13_ = NULL;
#line 155 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp13_ = g_strdup_printf ("[Data Source]\n" "DisplayName=%s\n" "Enabled=true\n" "Parent=local-stub\n" "\n" "[Address Book]\n" "BackendName=local\n", _data_->_tmp12_);
#line 155 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->source_file_content = _data_->_tmp13_;
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_state_ = 1;
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	e_source_registry_new (NULL, _eds_test_backend_prepare_source_async_ready, _data_);
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return FALSE;
#line 1369 "backend.c"
	_state_1:
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp14_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp14_ = e_source_registry_new_finish (_data_->_res_, &_data_->_inner_error_);
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->source_registry = _data_->_tmp14_;
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_data_->_inner_error_ != NULL) {
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_error_free (_data_->_inner_error_);
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_free0 (_data_->source_file_content);
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_data_->source_file);
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_data_->config_dir);
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_free0 (_data_->source_file_name);
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		block2_data_unref (_data_->_data2_);
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_data2_ = NULL;
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		if (_data_->_state_ == 0) {
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1399 "backend.c"
		} else {
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1403 "backend.c"
		}
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_object_unref (_data_->_async_result);
#line 164 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return FALSE;
#line 1409 "backend.c"
	}
#line 165 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp15_ = NULL;
#line 165 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp15_ = _data_->source_registry;
#line 165 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp16_ = NULL;
#line 165 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp16_ = _g_object_ref0 (_data_->_tmp15_);
#line 165 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->self->priv->_source_registry);
#line 165 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->self->priv->_source_registry = _data_->_tmp16_;
#line 166 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp17_ = NULL;
#line 166 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp17_ = _data_->source_registry;
#line 166 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp18_ = 0UL;
#line 166 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp18_ = g_signal_connect_data (_data_->_tmp17_, "source-added", (GCallback) ___lambda3__e_source_registry_source_added, block2_data_ref (_data_->_data2_), (GClosureNotify) block2_data_unref, 0);
#line 166 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->signal_id = _data_->_tmp18_;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp19_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp19_ = _data_->source_file;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp20_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp20_ = _data_->source_file_content;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp21_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp21__length1 = 0;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp21_ = string_get_data (_data_->_tmp20_, &_data_->_tmp21__length1);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp22_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp22__length1 = 0;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp22_ = _data_->_tmp21_;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp22__length1 = _data_->_tmp21__length1;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_state_ = 2;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_file_replace_contents_async (_data_->_tmp19_, _data_->_tmp22_, (gsize) _data_->_tmp22__length1, NULL, FALSE, G_FILE_CREATE_NONE, NULL, _eds_test_backend_prepare_source_async_ready, _data_);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return FALSE;
#line 1461 "backend.c"
	_state_2:
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_file_replace_contents_finish (_data_->_tmp19_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_data_->_inner_error_ != NULL) {
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_error_free (_data_->_inner_error_);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_data_->source_registry);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_free0 (_data_->source_file_content);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_data_->source_file);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_data_->config_dir);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_free0 (_data_->source_file_name);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		block2_data_unref (_data_->_data2_);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_data2_ = NULL;
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		if (_data_->_state_ == 0) {
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1489 "backend.c"
		} else {
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1493 "backend.c"
		}
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_object_unref (_data_->_async_result);
#line 173 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return FALSE;
#line 1499 "backend.c"
	}
#line 175 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp23_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp23_ = _data_->source_registry;
#line 175 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp24_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp24_ = _data_->self->priv->_addressbook_name;
#line 175 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp25_ = NULL;
#line 175 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp25_ = e_source_registry_ref_source (_data_->_tmp23_, _data_->_tmp24_);
#line 175 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->self->priv->_source);
#line 175 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->self->priv->_source = _data_->_tmp25_;
#line 176 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp26_ = NULL;
#line 176 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp26_ = _data_->self->priv->_source;
#line 176 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_data_->_tmp26_ == NULL) {
#line 178 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_state_ = 3;
#line 178 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return FALSE;
#line 1527 "backend.c"
		_state_3:
		;
	}
#line 182 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp27_ = NULL;
#line 182 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp27_ = _data_->self->priv->_source;
#line 182 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_vala_assert (_data_->_tmp27_ != NULL, "this._source != null");
#line 183 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp28_ = NULL;
#line 183 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp28_ = _data_->source_registry;
#line 183 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp29_ = 0UL;
#line 183 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp29_ = _data_->signal_id;
#line 183 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_signal_handler_disconnect ((GObject*) _data_->_tmp28_, _data_->_tmp29_);
#line 185 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp30_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp30_ = _data_->source_file;
#line 185 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp31_ = NULL;
#line 185 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp31_ = _g_object_ref0 (_data_->_tmp30_);
#line 185 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->self->priv->_source_file);
#line 185 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->self->priv->_source_file = _data_->_tmp31_;
#line 187 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp32_ = FALSE;
#line 187 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp32_ = _data_->is_default;
#line 187 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_data_->_tmp32_) {
#line 189 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		eds_test_backend_set_as_default (_data_->self);
#line 1567 "backend.c"
	}
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->source_registry);
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_free0 (_data_->source_file_content);
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->source_file);
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (_data_->config_dir);
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_free0 (_data_->source_file_name);
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	block2_data_unref (_data_->_data2_);
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_data2_ = NULL;
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_data_->_state_ == 0) {
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1587 "backend.c"
	} else {
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1591 "backend.c"
	}
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_object_unref (_data_->_async_result);
#line 146 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return FALSE;
#line 1597 "backend.c"
}


static void eds_test_backend_commit_contacts_to_addressbook_data_free (gpointer _data) {
	EdsTestBackendCommitContactsToAddressbookData* _data_;
	_data_ = _data;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_eds_test_backend_unref0 (_data_->self);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_slice_free (EdsTestBackendCommitContactsToAddressbookData, _data_);
#line 1608 "backend.c"
}


void eds_test_backend_commit_contacts_to_addressbook (EdsTestBackend* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	EdsTestBackendCommitContactsToAddressbookData* _data_;
	EdsTestBackend* _tmp0_ = NULL;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = g_slice_new0 (EdsTestBackendCommitContactsToAddressbookData);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, eds_test_backend_commit_contacts_to_addressbook);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, eds_test_backend_commit_contacts_to_addressbook_data_free);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = _eds_test_backend_ref0 (self);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->self = _tmp0_;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	eds_test_backend_commit_contacts_to_addressbook_co (_data_);
#line 1627 "backend.c"
}


void eds_test_backend_commit_contacts_to_addressbook_finish (EdsTestBackend* self, GAsyncResult* _res_) {
	EdsTestBackendCommitContactsToAddressbookData* _data_;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1635 "backend.c"
}


static void eds_test_backend_commit_contacts_to_addressbook_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	EdsTestBackendCommitContactsToAddressbookData* _data_;
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_ = _user_data_;
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_source_object_ = source_object;
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_res_ = _res_;
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	eds_test_backend_commit_contacts_to_addressbook_co (_data_);
#line 1649 "backend.c"
}


static void _g_free0_ (gpointer var) {
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	var = (g_free (var), NULL);
#line 1656 "backend.c"
}


static void _g_slist_free__g_free0_ (GSList* self) {
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_slist_foreach (self, (GFunc) _g_free0_, NULL);
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_slist_free (self);
#line 1665 "backend.c"
}


static void _vala_array_add1 (gchar*** array, int* length, int* size, gchar* value) {
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if ((*length) == (*size)) {
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 1676 "backend.c"
	}
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	(*array)[(*length)++] = value;
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	(*array)[*length] = NULL;
#line 1682 "backend.c"
}


static void _g_slist_free__g_object_unref0_ (GSList* self) {
#line 208 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_slist_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 208 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_slist_free (self);
#line 1691 "backend.c"
}


static gboolean eds_test_backend_commit_contacts_to_addressbook_co (EdsTestBackendCommitContactsToAddressbookData* _data_) {
#line 193 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	switch (_data_->_state_) {
#line 193 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 0:
#line 1700 "backend.c"
		goto _state_0;
#line 193 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		case 1:
#line 1704 "backend.c"
		goto _state_1;
		default:
#line 193 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_assert_not_reached ();
#line 1709 "backend.c"
	}
	_state_0:
#line 195 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->contacts = NULL;
#line 197 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->self->priv->_contacts = g_list_reverse (_data_->self->priv->_contacts);
#line 199 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0_ = NULL;
#line 199 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_data_->_tmp0_ = _data_->self->priv->_contacts;
#line 1720 "backend.c"
	{
#line 199 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->c_collection = _data_->_tmp0_;
#line 199 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		for (_data_->c_it = _data_->c_collection; _data_->c_it != NULL; _data_->c_it = _data_->c_it->next) {
#line 199 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_data_->_tmp1_ = NULL;
#line 199 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_data_->_tmp1_ = _g_object_ref0 ((GeeHashMap*) _data_->c_it->data);
#line 199 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_data_->c = _data_->_tmp1_;
#line 1732 "backend.c"
			{
#line 201 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->_tmp2_ = NULL;
#line 201 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->_tmp2_ = e_contact_new ();
#line 201 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->contact = _data_->_tmp2_;
#line 203 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->_tmp3_ = NULL;
#line 203 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->_tmp3_ = _data_->contact;
#line 203 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->_tmp4_ = NULL;
#line 203 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->_tmp4_ = _data_->c;
#line 203 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_eds_test_backend_set_contact_fields (_data_->self, _data_->_tmp3_, _data_->_tmp4_);
#line 205 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->_tmp5_ = NULL;
#line 205 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->_tmp5_ = _data_->contact;
#line 205 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->_tmp6_ = NULL;
#line 205 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->_tmp6_ = _g_object_ref0 (_data_->_tmp5_);
#line 205 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->contacts = g_slist_prepend (_data_->contacts, _data_->_tmp6_);
#line 199 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_g_object_unref0 (_data_->contact);
#line 199 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_g_object_unref0 (_data_->c);
#line 1764 "backend.c"
			}
		}
	}
	{
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp7_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp7_ = _data_->self->priv->_addressbook;
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp8_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp8_ = _data_->contacts;
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp9_ = NULL;
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_state_ = 1;
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e_book_client_add_contacts (_data_->_tmp7_, _data_->_tmp8_, NULL, eds_test_backend_commit_contacts_to_addressbook_ready, _data_);
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return FALSE;
#line 1785 "backend.c"
		_state_1:
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e_book_client_add_contacts_finish (_data_->_tmp7_, _data_->_res_, &_data_->_tmp9_, &_data_->_inner_error_);
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		__g_slist_free__g_free0_0 (_data_->uids);
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->uids = _data_->_tmp9_;
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		if (_data_->_inner_error_ != NULL) {
#line 212 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			__g_slist_free__g_free0_0 (_data_->uids);
#line 1797 "backend.c"
			goto __catch4_g_error;
		}
		{
#line 214 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_data_->uid_collection = _data_->uids;
#line 214 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			for (_data_->uid_it = _data_->uid_collection; _data_->uid_it != NULL; _data_->uid_it = _data_->uid_it->next) {
#line 214 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_data_->uid = (const gchar*) _data_->uid_it->data;
#line 1807 "backend.c"
				{
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_data_->_tmp10_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_data_->_tmp10__length1 = 0;
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_data_->_tmp10_ = _data_->self->priv->_e_contacts;
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_data_->_tmp10__length1 = _data_->self->priv->_e_contacts_length1;
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_data_->_tmp11_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_data_->_tmp11_ = _data_->uid;
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_data_->_tmp12_ = NULL;
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_data_->_tmp12_ = g_strdup (_data_->_tmp11_);
#line 215 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_vala_array_add1 (&_data_->self->priv->_e_contacts, &_data_->self->priv->_e_contacts_length1, &_data_->self->priv->__e_contacts_size_, _data_->_tmp12_);
#line 1827 "backend.c"
				}
			}
		}
#line 208 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		__g_slist_free__g_free0_0 (_data_->uids);
#line 1833 "backend.c"
	}
	goto __finally4;
	__catch4_g_error:
	{
#line 208 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->e = _data_->_inner_error_;
#line 208 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_inner_error_ = NULL;
#line 219 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp13_ = NULL;
#line 219 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp13_ = _data_->e;
#line 219 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp14_ = NULL;
#line 219 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_data_->_tmp14_ = _data_->_tmp13_->message;
#line 219 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_warning ("backend.vala:219: Couldn't add contacts: %s\n", _data_->_tmp14_);
#line 208 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_error_free0 (_data_->e);
#line 1854 "backend.c"
	}
	__finally4:
#line 208 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_data_->_inner_error_ != NULL) {
#line 208 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		__g_slist_free__g_object_unref0_0 (_data_->contacts);
#line 208 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 208 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_clear_error (&_data_->_inner_error_);
#line 208 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return FALSE;
#line 1867 "backend.c"
	}
#line 193 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	__g_slist_free__g_object_unref0_0 (_data_->contacts);
#line 193 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_data_->_state_ == 0) {
#line 193 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1875 "backend.c"
	} else {
#line 193 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1879 "backend.c"
	}
#line 193 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_object_unref (_data_->_async_result);
#line 193 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return FALSE;
#line 1885 "backend.c"
}


static gchar* string_slice (const gchar* self, glong start, glong end) {
	gchar* result = NULL;
	glong string_length = 0L;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	glong _tmp2_ = 0L;
	glong _tmp5_ = 0L;
	gboolean _tmp8_ = FALSE;
	glong _tmp9_ = 0L;
	gboolean _tmp12_ = FALSE;
	glong _tmp13_ = 0L;
	glong _tmp16_ = 0L;
	glong _tmp17_ = 0L;
	glong _tmp18_ = 0L;
	glong _tmp19_ = 0L;
	glong _tmp20_ = 0L;
	gchar* _tmp21_ = NULL;
#line 1226 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1227 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = strlen (self);
#line 1227 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = _tmp0_;
#line 1227 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	string_length = (glong) _tmp1_;
#line 1228 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp2_ = start;
#line 1228 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp2_ < ((glong) 0)) {
#line 1918 "backend.c"
		glong _tmp3_ = 0L;
		glong _tmp4_ = 0L;
#line 1229 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp3_ = string_length;
#line 1229 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp4_ = start;
#line 1229 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		start = _tmp3_ + _tmp4_;
#line 1927 "backend.c"
	}
#line 1231 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp5_ = end;
#line 1231 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp5_ < ((glong) 0)) {
#line 1933 "backend.c"
		glong _tmp6_ = 0L;
		glong _tmp7_ = 0L;
#line 1232 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp6_ = string_length;
#line 1232 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp7_ = end;
#line 1232 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		end = _tmp6_ + _tmp7_;
#line 1942 "backend.c"
	}
#line 1234 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp9_ = start;
#line 1234 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp9_ >= ((glong) 0)) {
#line 1948 "backend.c"
		glong _tmp10_ = 0L;
		glong _tmp11_ = 0L;
#line 1234 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp10_ = start;
#line 1234 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp11_ = string_length;
#line 1234 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp8_ = _tmp10_ <= _tmp11_;
#line 1957 "backend.c"
	} else {
#line 1234 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp8_ = FALSE;
#line 1961 "backend.c"
	}
#line 1234 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp8_, NULL);
#line 1235 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp13_ = end;
#line 1235 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp13_ >= ((glong) 0)) {
#line 1969 "backend.c"
		glong _tmp14_ = 0L;
		glong _tmp15_ = 0L;
#line 1235 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp14_ = end;
#line 1235 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp15_ = string_length;
#line 1235 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp12_ = _tmp14_ <= _tmp15_;
#line 1978 "backend.c"
	} else {
#line 1235 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp12_ = FALSE;
#line 1982 "backend.c"
	}
#line 1235 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp12_, NULL);
#line 1236 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp16_ = start;
#line 1236 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp17_ = end;
#line 1236 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (_tmp16_ <= _tmp17_, NULL);
#line 1237 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp18_ = start;
#line 1237 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp19_ = end;
#line 1237 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp20_ = start;
#line 1237 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp21_ = g_strndup (((gchar*) self) + _tmp18_, (gsize) (_tmp19_ - _tmp20_));
#line 1237 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	result = _tmp21_;
#line 1237 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	return result;
#line 2004 "backend.c"
}


static void _vala_GValue_free (GValue* self) {
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_value_unset (self);
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_free (self);
#line 2013 "backend.c"
}


static gint string_index_of (const gchar* self, const gchar* needle, gint start_index) {
	gint result = 0;
	gchar* _result_ = NULL;
	gint _tmp0_ = 0;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
#line 900 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 900 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, 0);
#line 901 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp0_ = start_index;
#line 901 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp1_ = needle;
#line 901 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp2_ = strstr (((gchar*) self) + _tmp0_, (gchar*) _tmp1_);
#line 901 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_result_ = _tmp2_;
#line 903 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	_tmp3_ = _result_;
#line 903 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
	if (_tmp3_ != NULL) {
#line 2040 "backend.c"
		gchar* _tmp4_ = NULL;
#line 904 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		_tmp4_ = _result_;
#line 904 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		result = (gint) (_tmp4_ - ((gchar*) self));
#line 904 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		return result;
#line 2048 "backend.c"
	} else {
#line 906 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		result = -1;
#line 906 "/opt/gnome3/build/share/vala-0.26/vapi/glib-2.0.vapi"
		return result;
#line 2054 "backend.c"
	}
}


static void _vala_EContactPhoto_free (EContactPhoto* self) {
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_boxed_free (e_contact_photo_get_type (), self);
#line 2062 "backend.c"
}


static void _vala_EContactName_free (EContactName* self) {
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_boxed_free (e_contact_name_get_type (), self);
#line 2069 "backend.c"
}


static void _vala_EContactAddress_free (EContactAddress* self) {
#line 302 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_boxed_free (e_contact_address_get_type (), self);
#line 2076 "backend.c"
}


static void _eds_test_backend_set_contact_fields (EdsTestBackend* self, EContact* contact, GeeHashMap* c) {
	gboolean added_contact_name = FALSE;
	EContactName* contact_name = NULL;
	EContactName* _tmp0_ = NULL;
	gchar* contact_field_name = NULL;
	gchar* _tmp1_ = NULL;
	gint min_len = 0;
	const gchar* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gboolean _tmp198_ = FALSE;
	GError * _inner_error_ = NULL;
#line 224 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (self != NULL);
#line 224 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (contact != NULL);
#line 224 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (c != NULL);
#line 227 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	added_contact_name = FALSE;
#line 228 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = e_contact_name_new ();
#line 228 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	contact_name = _tmp0_;
#line 229 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp1_ = g_strdup ("contact_name");
#line 229 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	contact_field_name = _tmp1_;
#line 230 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp2_ = contact_field_name;
#line 230 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp3_ = strlen (_tmp2_);
#line 230 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp4_ = _tmp3_;
#line 230 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	min_len = _tmp4_;
#line 2116 "backend.c"
	{
		GeeIterator* _k_it = NULL;
		GeeHashMap* _tmp5_ = NULL;
		GeeSet* _tmp6_ = NULL;
		GeeSet* _tmp7_ = NULL;
		GeeSet* _tmp8_ = NULL;
		GeeIterator* _tmp9_ = NULL;
		GeeIterator* _tmp10_ = NULL;
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp5_ = c;
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp6_ = gee_abstract_map_get_keys ((GeeMap*) _tmp5_);
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp7_ = _tmp6_;
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp8_ = _tmp7_;
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp9_ = gee_iterable_iterator ((GeeIterable*) _tmp8_);
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp10_ = _tmp9_;
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_tmp8_);
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_k_it = _tmp10_;
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		while (TRUE) {
#line 2143 "backend.c"
			GeeIterator* _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
			gchar* k = NULL;
			GeeIterator* _tmp13_ = NULL;
			gpointer _tmp14_ = NULL;
			gboolean _tmp15_ = FALSE;
			const gchar* _tmp16_ = NULL;
			gint _tmp17_ = 0;
			gint _tmp18_ = 0;
			gint _tmp19_ = 0;
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_tmp11_ = _k_it;
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_tmp12_ = gee_iterator_next (_tmp11_);
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			if (!_tmp12_) {
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				break;
#line 2162 "backend.c"
			}
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_tmp13_ = _k_it;
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_tmp14_ = gee_iterator_get (_tmp13_);
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			k = (gchar*) _tmp14_;
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_tmp16_ = k;
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_tmp17_ = strlen (_tmp16_);
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_tmp18_ = _tmp17_;
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_tmp19_ = min_len;
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			if (_tmp18_ > _tmp19_) {
#line 2180 "backend.c"
				const gchar* _tmp20_ = NULL;
				gint _tmp21_ = 0;
				gchar* _tmp22_ = NULL;
				gchar* _tmp23_ = NULL;
				const gchar* _tmp24_ = NULL;
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp20_ = k;
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp21_ = min_len;
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp22_ = string_slice (_tmp20_, (glong) 0, (glong) _tmp21_);
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp23_ = _tmp22_;
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp24_ = contact_field_name;
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp15_ = g_strcmp0 (_tmp23_, _tmp24_) == 0;
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_g_free0 (_tmp23_);
#line 2200 "backend.c"
			} else {
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp15_ = FALSE;
#line 2204 "backend.c"
			}
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			if (_tmp15_) {
#line 2208 "backend.c"
				gchar* v = NULL;
				GeeHashMap* _tmp25_ = NULL;
				const gchar* _tmp26_ = NULL;
				gpointer _tmp27_ = NULL;
				GValue* _tmp28_ = NULL;
				GValue _tmp29_ = {0};
				const gchar* _tmp30_ = NULL;
				gchar* _tmp31_ = NULL;
				gchar* _tmp32_ = NULL;
				const gchar* _tmp33_ = NULL;
				gint _tmp34_ = 0;
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp25_ = c;
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp26_ = k;
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp27_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp25_, _tmp26_);
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp28_ = (GValue*) _tmp27_;
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp29_ = *_tmp28_;
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp30_ = g_value_get_string (&_tmp29_);
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp31_ = g_strdup (_tmp30_);
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp32_ = _tmp31_;
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				__vala_GValue_free0 (_tmp28_);
#line 236 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				v = _tmp32_;
#line 237 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp33_ = k;
#line 237 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp34_ = string_index_of (_tmp33_, "family", 0);
#line 237 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				if (_tmp34_ >= 0) {
#line 2246 "backend.c"
					EContactName* _tmp35_ = NULL;
					const gchar* _tmp36_ = NULL;
					gchar* _tmp37_ = NULL;
#line 239 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp35_ = contact_name;
#line 239 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp36_ = v;
#line 239 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp37_ = g_strdup (_tmp36_);
#line 239 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_g_free0 (_tmp35_->family);
#line 239 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp35_->family = _tmp37_;
#line 2260 "backend.c"
				} else {
					const gchar* _tmp38_ = NULL;
					gint _tmp39_ = 0;
#line 241 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp38_ = k;
#line 241 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp39_ = string_index_of (_tmp38_, "given", 0);
#line 241 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					if (_tmp39_ >= 0) {
#line 2270 "backend.c"
						EContactName* _tmp40_ = NULL;
						const gchar* _tmp41_ = NULL;
						gchar* _tmp42_ = NULL;
#line 243 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp40_ = contact_name;
#line 243 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp41_ = v;
#line 243 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp42_ = g_strdup (_tmp41_);
#line 243 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_g_free0 (_tmp40_->given);
#line 243 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp40_->given = _tmp42_;
#line 2284 "backend.c"
					} else {
						const gchar* _tmp43_ = NULL;
						gint _tmp44_ = 0;
#line 245 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp43_ = k;
#line 245 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp44_ = string_index_of (_tmp43_, "additional", 0);
#line 245 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						if (_tmp44_ >= 0) {
#line 2294 "backend.c"
							EContactName* _tmp45_ = NULL;
							const gchar* _tmp46_ = NULL;
							gchar* _tmp47_ = NULL;
#line 247 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp45_ = contact_name;
#line 247 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp46_ = v;
#line 247 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp47_ = g_strdup (_tmp46_);
#line 247 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_g_free0 (_tmp45_->additional);
#line 247 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp45_->additional = _tmp47_;
#line 2308 "backend.c"
						} else {
							const gchar* _tmp48_ = NULL;
							gint _tmp49_ = 0;
#line 249 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp48_ = k;
#line 249 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp49_ = string_index_of (_tmp48_, "prefixes", 0);
#line 249 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							if (_tmp49_ >= 0) {
#line 2318 "backend.c"
								EContactName* _tmp50_ = NULL;
								const gchar* _tmp51_ = NULL;
								gchar* _tmp52_ = NULL;
#line 251 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp50_ = contact_name;
#line 251 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp51_ = v;
#line 251 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp52_ = g_strdup (_tmp51_);
#line 251 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_free0 (_tmp50_->prefixes);
#line 251 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp50_->prefixes = _tmp52_;
#line 2332 "backend.c"
							} else {
								const gchar* _tmp53_ = NULL;
								gint _tmp54_ = 0;
#line 253 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp53_ = k;
#line 253 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp54_ = string_index_of (_tmp53_, "suffixes", 0);
#line 253 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								if (_tmp54_ >= 0) {
#line 2342 "backend.c"
									EContactName* _tmp55_ = NULL;
									const gchar* _tmp56_ = NULL;
									gchar* _tmp57_ = NULL;
#line 255 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp55_ = contact_name;
#line 255 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp56_ = v;
#line 255 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp57_ = g_strdup (_tmp56_);
#line 255 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_g_free0 (_tmp55_->suffixes);
#line 255 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp55_->suffixes = _tmp57_;
#line 2356 "backend.c"
								}
							}
						}
					}
				}
#line 258 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				added_contact_name = TRUE;
#line 234 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_g_free0 (v);
#line 2366 "backend.c"
			} else {
				const gchar* _tmp58_ = NULL;
#line 260 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp58_ = k;
#line 260 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				if (g_strcmp0 (_tmp58_, "avatar") == 0) {
#line 2373 "backend.c"
					gchar* v = NULL;
					GeeHashMap* _tmp59_ = NULL;
					const gchar* _tmp60_ = NULL;
					gpointer _tmp61_ = NULL;
					GValue* _tmp62_ = NULL;
					GValue _tmp63_ = {0};
					const gchar* _tmp64_ = NULL;
					gchar* _tmp65_ = NULL;
					gchar* _tmp66_ = NULL;
					guint8* photo_content = NULL;
					gint photo_content_length1 = 0;
					gint _photo_content_size_ = 0;
					GFile* file = NULL;
					const gchar* _tmp67_ = NULL;
					GFile* _tmp68_ = NULL;
#line 262 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp59_ = c;
#line 262 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp60_ = k;
#line 262 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp61_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp59_, _tmp60_);
#line 262 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp62_ = (GValue*) _tmp61_;
#line 262 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp63_ = *_tmp62_;
#line 262 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp64_ = g_value_get_string (&_tmp63_);
#line 262 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp65_ = g_strdup (_tmp64_);
#line 262 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp66_ = _tmp65_;
#line 262 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					__vala_GValue_free0 (_tmp62_);
#line 262 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					v = _tmp66_;
#line 264 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp67_ = v;
#line 264 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp68_ = g_file_new_for_path (_tmp67_);
#line 264 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					file = _tmp68_;
#line 2415 "backend.c"
					{
						GFile* _tmp69_ = NULL;
						guint8* _tmp70_ = NULL;
						gsize _tmp71_;
						EContactPhoto* cp = NULL;
						EContactPhoto* _tmp72_ = NULL;
						EContactPhoto* _tmp73_ = NULL;
						EContactPhoto* _tmp74_ = NULL;
						guint8* _tmp75_ = NULL;
						gint _tmp75__length1 = 0;
						EContact* _tmp76_ = NULL;
						EContactField _tmp77_ = 0;
						EContactPhoto* _tmp78_ = NULL;
#line 268 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp69_ = file;
#line 268 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						g_file_load_contents (_tmp69_, NULL, &_tmp70_, &_tmp71_, NULL, &_inner_error_);
#line 268 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						photo_content = (g_free (photo_content), NULL);
#line 268 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						photo_content = _tmp70_;
#line 268 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						photo_content_length1 = _tmp71_;
#line 268 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_photo_content_size_ = photo_content_length1;
#line 268 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						if (_inner_error_ != NULL) {
#line 2443 "backend.c"
							goto __catch5_g_error;
						}
#line 270 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp72_ = e_contact_photo_new ();
#line 270 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						cp = _tmp72_;
#line 271 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp73_ = cp;
#line 271 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp73_->type = E_CONTACT_PHOTO_TYPE_INLINED;
#line 272 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp74_ = cp;
#line 272 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp75_ = photo_content;
#line 272 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp75__length1 = photo_content_length1;
#line 272 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						e_contact_photo_set_inlined (_tmp74_, _tmp75_, (gsize) _tmp75__length1);
#line 274 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp76_ = contact;
#line 274 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp77_ = e_contact_field_id ("photo");
#line 274 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp78_ = cp;
#line 274 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						e_contact_set (_tmp76_, _tmp77_, _tmp78_);
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						__vala_EContactPhoto_free0 (cp);
#line 2472 "backend.c"
					}
					goto __finally5;
					__catch5_g_error:
					{
						GError* e = NULL;
						const gchar* _tmp79_ = NULL;
						GError* _tmp80_ = NULL;
						const gchar* _tmp81_ = NULL;
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						e = _inner_error_;
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_inner_error_ = NULL;
#line 278 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp79_ = v;
#line 278 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp80_ = e;
#line 278 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp81_ = _tmp80_->message;
#line 278 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						g_warning ("backend.vala:278: \n\nCan't load avatar %s: %s\n\n", _tmp79_, _tmp81_);
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_g_error_free0 (e);
#line 2495 "backend.c"
					}
					__finally5:
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					if (_inner_error_ != NULL) {
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_g_object_unref0 (file);
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						photo_content = (g_free (photo_content), NULL);
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_g_free0 (v);
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_g_free0 (k);
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_g_object_unref0 (_k_it);
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_g_free0 (contact_field_name);
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						__vala_EContactName_free0 (contact_name);
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						g_clear_error (&_inner_error_);
#line 266 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						return;
#line 2520 "backend.c"
					}
#line 260 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_g_object_unref0 (file);
#line 260 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					photo_content = (g_free (photo_content), NULL);
#line 260 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_g_free0 (v);
#line 2528 "backend.c"
				} else {
					const gchar* _tmp82_ = NULL;
#line 282 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					_tmp82_ = k;
#line 282 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
					if (g_strcmp0 (_tmp82_, "email_addresses") == 0) {
#line 2535 "backend.c"
						gchar* v = NULL;
						GeeHashMap* _tmp83_ = NULL;
						const gchar* _tmp84_ = NULL;
						gpointer _tmp85_ = NULL;
						GValue* _tmp86_ = NULL;
						GValue _tmp87_ = {0};
						const gchar* _tmp88_ = NULL;
						gchar* _tmp89_ = NULL;
						gchar* _tmp90_ = NULL;
						gchar** addresses = NULL;
						const gchar* _tmp91_ = NULL;
						gchar** _tmp92_ = NULL;
						gchar** _tmp93_ = NULL;
						gint addresses_length1 = 0;
						gint _addresses_size_ = 0;
						gchar** _tmp94_ = NULL;
						gint _tmp94__length1 = 0;
#line 284 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp83_ = c;
#line 284 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp84_ = k;
#line 284 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp85_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp83_, _tmp84_);
#line 284 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp86_ = (GValue*) _tmp85_;
#line 284 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp87_ = *_tmp86_;
#line 284 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp88_ = g_value_get_string (&_tmp87_);
#line 284 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp89_ = g_strdup (_tmp88_);
#line 284 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp90_ = _tmp89_;
#line 284 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						__vala_GValue_free0 (_tmp86_);
#line 284 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						v = _tmp90_;
#line 285 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp91_ = v;
#line 285 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp93_ = _tmp92_ = g_strsplit (_tmp91_, ",", 0);
#line 285 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						addresses = _tmp93_;
#line 285 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						addresses_length1 = _vala_array_length (_tmp92_);
#line 285 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_addresses_size_ = addresses_length1;
#line 287 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp94_ = addresses;
#line 287 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp94__length1 = addresses_length1;
#line 2587 "backend.c"
						{
							gchar** addr_collection = NULL;
							gint addr_collection_length1 = 0;
							gint _addr_collection_size_ = 0;
							gint addr_it = 0;
#line 287 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							addr_collection = _tmp94_;
#line 287 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							addr_collection_length1 = _tmp94__length1;
#line 287 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							for (addr_it = 0; addr_it < _tmp94__length1; addr_it = addr_it + 1) {
#line 2599 "backend.c"
								gchar* _tmp95_ = NULL;
								gchar* addr = NULL;
#line 287 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp95_ = g_strdup (addr_collection[addr_it]);
#line 287 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								addr = _tmp95_;
#line 2606 "backend.c"
								{
									EContact* _tmp96_ = NULL;
									EContactField _tmp97_ = 0;
									const gchar* _tmp98_ = NULL;
#line 289 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp96_ = contact;
#line 289 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp97_ = e_contact_field_id ("email");
#line 289 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp98_ = addr;
#line 289 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									e_contact_set (_tmp96_, _tmp97_, _tmp98_);
#line 287 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_g_free0 (addr);
#line 2621 "backend.c"
								}
							}
						}
#line 282 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						addresses = (_vala_array_free (addresses, addresses_length1, (GDestroyNotify) g_free), NULL);
#line 282 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_g_free0 (v);
#line 2629 "backend.c"
					} else {
						const gchar* _tmp99_ = NULL;
#line 292 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						_tmp99_ = k;
#line 292 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
						if (g_strcmp0 (_tmp99_, "im_addresses") == 0) {
#line 2636 "backend.c"
							gchar* v = NULL;
							GeeHashMap* _tmp100_ = NULL;
							const gchar* _tmp101_ = NULL;
							gpointer _tmp102_ = NULL;
							GValue* _tmp103_ = NULL;
							GValue _tmp104_ = {0};
							const gchar* _tmp105_ = NULL;
							gchar* _tmp106_ = NULL;
							gchar* _tmp107_ = NULL;
							GeeHashMap* addresses = NULL;
							const gchar* _tmp108_ = NULL;
							GeeHashMap* _tmp109_ = NULL;
#line 294 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp100_ = c;
#line 294 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp101_ = k;
#line 294 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp102_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp100_, _tmp101_);
#line 294 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp103_ = (GValue*) _tmp102_;
#line 294 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp104_ = *_tmp103_;
#line 294 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp105_ = g_value_get_string (&_tmp104_);
#line 294 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp106_ = g_strdup (_tmp105_);
#line 294 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp107_ = _tmp106_;
#line 294 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							__vala_GValue_free0 (_tmp103_);
#line 294 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							v = _tmp107_;
#line 295 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp108_ = v;
#line 295 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp109_ = _eds_test_backend_parse_im_addrs (self, _tmp108_);
#line 295 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							addresses = _tmp109_;
#line 2675 "backend.c"
							{
								GeeIterator* _addr_it = NULL;
								GeeHashMap* _tmp110_ = NULL;
								GeeSet* _tmp111_ = NULL;
								GeeSet* _tmp112_ = NULL;
								GeeSet* _tmp113_ = NULL;
								GeeIterator* _tmp114_ = NULL;
								GeeIterator* _tmp115_ = NULL;
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp110_ = addresses;
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp111_ = gee_abstract_map_get_keys ((GeeMap*) _tmp110_);
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp112_ = _tmp111_;
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp113_ = _tmp112_;
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp114_ = gee_iterable_iterator ((GeeIterable*) _tmp113_);
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp115_ = _tmp114_;
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_object_unref0 (_tmp113_);
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_addr_it = _tmp115_;
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								while (TRUE) {
#line 2702 "backend.c"
									GeeIterator* _tmp116_ = NULL;
									gboolean _tmp117_ = FALSE;
									gchar* addr = NULL;
									GeeIterator* _tmp118_ = NULL;
									gpointer _tmp119_ = NULL;
									gchar* proto = NULL;
									GeeHashMap* _tmp120_ = NULL;
									const gchar* _tmp121_ = NULL;
									gpointer _tmp122_ = NULL;
									EContact* _tmp123_ = NULL;
									const gchar* _tmp124_ = NULL;
									EContactField _tmp125_ = 0;
									const gchar* _tmp126_ = NULL;
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp116_ = _addr_it;
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp117_ = gee_iterator_next (_tmp116_);
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									if (!_tmp117_) {
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
										break;
#line 2724 "backend.c"
									}
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp118_ = _addr_it;
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp119_ = gee_iterator_get (_tmp118_);
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									addr = (gchar*) _tmp119_;
#line 298 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp120_ = addresses;
#line 298 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp121_ = addr;
#line 298 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp122_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp120_, _tmp121_);
#line 298 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									proto = (gchar*) _tmp122_;
#line 299 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp123_ = contact;
#line 299 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp124_ = proto;
#line 299 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp125_ = e_contact_field_id (_tmp124_);
#line 299 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_tmp126_ = addr;
#line 299 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									e_contact_set (_tmp123_, _tmp125_, _tmp126_);
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_g_free0 (proto);
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
									_g_free0 (addr);
#line 2754 "backend.c"
								}
#line 296 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_object_unref0 (_addr_it);
#line 2758 "backend.c"
							}
#line 292 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_g_object_unref0 (addresses);
#line 292 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_g_free0 (v);
#line 2764 "backend.c"
						} else {
							const gchar* _tmp127_ = NULL;
							const gchar* _tmp128_ = NULL;
#line 302 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp127_ = k;
#line 302 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							_tmp128_ = EDSF_PERSONA_address_fields[0];
#line 302 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
							if (g_strcmp0 (_tmp127_, _tmp128_) == 0) {
#line 2774 "backend.c"
								FolksPostalAddressFieldDetails* pa_fd = NULL;
								GeeHashMap* _tmp129_ = NULL;
								const gchar* _tmp130_ = NULL;
								gpointer _tmp131_ = NULL;
								GValue* _tmp132_ = NULL;
								GValue _tmp133_ = {0};
								GObject* _tmp134_ = NULL;
								FolksPostalAddressFieldDetails* _tmp135_ = NULL;
								FolksPostalAddressFieldDetails* _tmp136_ = NULL;
								FolksPostalAddress* pa = NULL;
								FolksPostalAddressFieldDetails* _tmp137_ = NULL;
								gconstpointer _tmp138_ = NULL;
								FolksPostalAddress* _tmp139_ = NULL;
								FolksPostalAddress* _tmp140_ = NULL;
								EContactAddress* address = NULL;
								EContactAddress* _tmp141_ = NULL;
								EContactAddress* _tmp142_ = NULL;
								FolksPostalAddress* _tmp143_ = NULL;
								const gchar* _tmp144_ = NULL;
								const gchar* _tmp145_ = NULL;
								gchar* _tmp146_ = NULL;
								EContactAddress* _tmp147_ = NULL;
								FolksPostalAddress* _tmp148_ = NULL;
								const gchar* _tmp149_ = NULL;
								const gchar* _tmp150_ = NULL;
								gchar* _tmp151_ = NULL;
								EContactAddress* _tmp152_ = NULL;
								FolksPostalAddress* _tmp153_ = NULL;
								const gchar* _tmp154_ = NULL;
								const gchar* _tmp155_ = NULL;
								gchar* _tmp156_ = NULL;
								EContactAddress* _tmp157_ = NULL;
								FolksPostalAddress* _tmp158_ = NULL;
								const gchar* _tmp159_ = NULL;
								const gchar* _tmp160_ = NULL;
								gchar* _tmp161_ = NULL;
								EContactAddress* _tmp162_ = NULL;
								FolksPostalAddress* _tmp163_ = NULL;
								const gchar* _tmp164_ = NULL;
								const gchar* _tmp165_ = NULL;
								gchar* _tmp166_ = NULL;
								EContactAddress* _tmp167_ = NULL;
								FolksPostalAddress* _tmp168_ = NULL;
								const gchar* _tmp169_ = NULL;
								const gchar* _tmp170_ = NULL;
								gchar* _tmp171_ = NULL;
								EContactAddress* _tmp172_ = NULL;
								FolksPostalAddress* _tmp173_ = NULL;
								const gchar* _tmp174_ = NULL;
								const gchar* _tmp175_ = NULL;
								gchar* _tmp176_ = NULL;
								EContactAddress* _tmp177_ = NULL;
								FolksPostalAddress* _tmp178_ = NULL;
								const gchar* _tmp179_ = NULL;
								const gchar* _tmp180_ = NULL;
								gchar* _tmp181_ = NULL;
								EContact* _tmp182_ = NULL;
								const gchar* _tmp183_ = NULL;
								EContactField _tmp184_ = 0;
								EContactAddress* _tmp185_ = NULL;
#line 304 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp129_ = c;
#line 304 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp130_ = k;
#line 304 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp131_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp129_, _tmp130_);
#line 304 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp132_ = (GValue*) _tmp131_;
#line 304 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp133_ = *_tmp132_;
#line 304 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp134_ = g_value_get_object (&_tmp133_);
#line 304 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp135_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp134_, FOLKS_TYPE_POSTAL_ADDRESS_FIELD_DETAILS, FolksPostalAddressFieldDetails));
#line 304 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp136_ = _tmp135_;
#line 304 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								__vala_GValue_free0 (_tmp132_);
#line 304 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								pa_fd = _tmp136_;
#line 305 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp137_ = pa_fd;
#line 305 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp138_ = folks_abstract_field_details_get_value ((FolksAbstractFieldDetails*) _tmp137_);
#line 305 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp139_ = _tmp138_;
#line 305 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp140_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST ((FolksPostalAddress*) _tmp139_, FOLKS_TYPE_POSTAL_ADDRESS, FolksPostalAddress));
#line 305 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								pa = _tmp140_;
#line 306 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp141_ = e_contact_address_new ();
#line 306 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								address = _tmp141_;
#line 307 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp142_ = address;
#line 307 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp143_ = pa;
#line 307 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp144_ = folks_postal_address_get_po_box (_tmp143_);
#line 307 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp145_ = _tmp144_;
#line 307 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp146_ = g_strdup (_tmp145_);
#line 307 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_free0 (_tmp142_->po);
#line 307 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp142_->po = _tmp146_;
#line 308 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp147_ = address;
#line 308 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp148_ = pa;
#line 308 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp149_ = folks_postal_address_get_extension (_tmp148_);
#line 308 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp150_ = _tmp149_;
#line 308 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp151_ = g_strdup (_tmp150_);
#line 308 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_free0 (_tmp147_->ext);
#line 308 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp147_->ext = _tmp151_;
#line 309 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp152_ = address;
#line 309 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp153_ = pa;
#line 309 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp154_ = folks_postal_address_get_street (_tmp153_);
#line 309 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp155_ = _tmp154_;
#line 309 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp156_ = g_strdup (_tmp155_);
#line 309 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_free0 (_tmp152_->street);
#line 309 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp152_->street = _tmp156_;
#line 310 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp157_ = address;
#line 310 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp158_ = pa;
#line 310 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp159_ = folks_postal_address_get_locality (_tmp158_);
#line 310 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp160_ = _tmp159_;
#line 310 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp161_ = g_strdup (_tmp160_);
#line 310 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_free0 (_tmp157_->locality);
#line 310 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp157_->locality = _tmp161_;
#line 311 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp162_ = address;
#line 311 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp163_ = pa;
#line 311 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp164_ = folks_postal_address_get_region (_tmp163_);
#line 311 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp165_ = _tmp164_;
#line 311 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp166_ = g_strdup (_tmp165_);
#line 311 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_free0 (_tmp162_->region);
#line 311 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp162_->region = _tmp166_;
#line 312 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp167_ = address;
#line 312 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp168_ = pa;
#line 312 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp169_ = folks_postal_address_get_postal_code (_tmp168_);
#line 312 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp170_ = _tmp169_;
#line 312 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp171_ = g_strdup (_tmp170_);
#line 312 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_free0 (_tmp167_->code);
#line 312 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp167_->code = _tmp171_;
#line 313 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp172_ = address;
#line 313 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp173_ = pa;
#line 313 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp174_ = folks_postal_address_get_country (_tmp173_);
#line 313 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp175_ = _tmp174_;
#line 313 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp176_ = g_strdup (_tmp175_);
#line 313 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_free0 (_tmp172_->country);
#line 313 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp172_->country = _tmp176_;
#line 314 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp177_ = address;
#line 314 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp178_ = pa;
#line 314 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp179_ = folks_postal_address_get_address_format (_tmp178_);
#line 314 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp180_ = _tmp179_;
#line 314 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp181_ = g_strdup (_tmp180_);
#line 314 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_free0 (_tmp177_->address_format);
#line 314 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp177_->address_format = _tmp181_;
#line 316 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp182_ = contact;
#line 316 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp183_ = k;
#line 316 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp184_ = e_contact_field_id (_tmp183_);
#line 316 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp185_ = address;
#line 316 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								e_contact_set (_tmp182_, _tmp184_, _tmp185_);
#line 302 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								__vala_EContactAddress_free0 (address);
#line 302 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_object_unref0 (pa);
#line 302 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_object_unref0 (pa_fd);
#line 2997 "backend.c"
							} else {
								gchar* v = NULL;
								GeeHashMap* _tmp186_ = NULL;
								const gchar* _tmp187_ = NULL;
								gpointer _tmp188_ = NULL;
								GValue* _tmp189_ = NULL;
								GValue _tmp190_ = {0};
								const gchar* _tmp191_ = NULL;
								gchar* _tmp192_ = NULL;
								gchar* _tmp193_ = NULL;
								EContact* _tmp194_ = NULL;
								const gchar* _tmp195_ = NULL;
								EContactField _tmp196_ = 0;
								const gchar* _tmp197_ = NULL;
#line 320 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp186_ = c;
#line 320 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp187_ = k;
#line 320 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp188_ = gee_abstract_map_get ((GeeAbstractMap*) _tmp186_, _tmp187_);
#line 320 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp189_ = (GValue*) _tmp188_;
#line 320 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp190_ = *_tmp189_;
#line 320 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp191_ = g_value_get_string (&_tmp190_);
#line 320 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp192_ = g_strdup (_tmp191_);
#line 320 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp193_ = _tmp192_;
#line 320 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								__vala_GValue_free0 (_tmp189_);
#line 320 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								v = _tmp193_;
#line 321 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp194_ = contact;
#line 321 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp195_ = k;
#line 321 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp196_ = e_contact_field_id (_tmp195_);
#line 321 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_tmp197_ = v;
#line 321 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								e_contact_set (_tmp194_, _tmp196_, _tmp197_);
#line 302 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
								_g_free0 (v);
#line 3044 "backend.c"
							}
						}
					}
				}
			}
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_g_free0 (k);
#line 3052 "backend.c"
		}
#line 232 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (_k_it);
#line 3056 "backend.c"
	}
#line 324 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp198_ = added_contact_name;
#line 324 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_tmp198_) {
#line 3062 "backend.c"
		EContact* _tmp199_ = NULL;
		EContactField _tmp200_ = 0;
		EContactName* _tmp201_ = NULL;
#line 326 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp199_ = contact;
#line 326 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp200_ = e_contact_field_id ("name");
#line 326 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp201_ = contact_name;
#line 326 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e_contact_set (_tmp199_, _tmp200_, _tmp201_);
#line 3074 "backend.c"
	}
#line 224 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_free0 (contact_field_name);
#line 224 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	__vala_EContactName_free0 (contact_name);
#line 3080 "backend.c"
}


void eds_test_backend_tear_down (EdsTestBackend* self) {
	GError * _inner_error_ = NULL;
#line 330 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (self != NULL);
#line 332 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_setenv ("FOLKS_BACKEND_EDS_USE_ADDRESS_BOOKS", "", TRUE);
#line 3090 "backend.c"
	{
		GFile* _tmp0_ = NULL;
#line 337 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp0_ = self->priv->_source_file;
#line 337 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		if (_tmp0_ != NULL) {
#line 3097 "backend.c"
			GFile* _tmp1_ = NULL;
#line 339 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_tmp1_ = self->priv->_source_file;
#line 339 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			g_file_delete (_tmp1_, NULL, &_inner_error_);
#line 339 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			if (_inner_error_ != NULL) {
#line 3105 "backend.c"
				goto __catch6_g_error;
			}
		}
	}
	goto __finally6;
	__catch6_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp2_ = NULL;
		GError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
#line 335 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		e = _inner_error_;
#line 335 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_inner_error_ = NULL;
#line 344 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp2_ = self->priv->_addressbook_name;
#line 344 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp3_ = e;
#line 344 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_tmp4_ = _tmp3_->message;
#line 344 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_warning ("backend.vala:344: Unable to remove addressbook ‘%s’: %s", _tmp2_, _tmp4_);
#line 335 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_error_free0 (e);
#line 3131 "backend.c"
	}
	__finally6:
	{
#line 349 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (self->priv->_source_file);
#line 349 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		self->priv->_source_file = NULL;
#line 350 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (self->priv->_source);
#line 350 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		self->priv->_source = NULL;
#line 351 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (self->priv->_addressbook);
#line 351 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		self->priv->_addressbook = NULL;
#line 352 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		_g_object_unref0 (self->priv->_source_registry);
#line 352 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		self->priv->_source_registry = NULL;
#line 3151 "backend.c"
	}
#line 335 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (_inner_error_ != NULL) {
#line 335 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 335 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_clear_error (&_inner_error_);
#line 335 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return;
#line 3161 "backend.c"
	}
}


static GeeHashMap* _eds_test_backend_parse_im_addrs (EdsTestBackend* self, const gchar* addr_str) {
	GeeHashMap* result = NULL;
	GeeHashMap* ret = NULL;
	GeeHashMap* _tmp0_ = NULL;
	gchar** im_addrs = NULL;
	const gchar* _tmp1_ = NULL;
	gchar** _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint im_addrs_length1 = 0;
	gint _im_addrs_size_ = 0;
	gchar** _tmp4_ = NULL;
	gint _tmp4__length1 = 0;
#line 356 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 356 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_val_if_fail (addr_str != NULL, NULL);
#line 358 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = gee_hash_map_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL);
#line 358 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	ret = _tmp0_;
#line 359 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp1_ = addr_str;
#line 359 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp3_ = _tmp2_ = g_strsplit (_tmp1_, ",", 0);
#line 359 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	im_addrs = _tmp3_;
#line 359 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	im_addrs_length1 = _vala_array_length (_tmp2_);
#line 359 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_im_addrs_size_ = im_addrs_length1;
#line 361 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp4_ = im_addrs;
#line 361 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp4__length1 = im_addrs_length1;
#line 3200 "backend.c"
	{
		gchar** a_collection = NULL;
		gint a_collection_length1 = 0;
		gint _a_collection_size_ = 0;
		gint a_it = 0;
#line 361 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		a_collection = _tmp4_;
#line 361 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		a_collection_length1 = _tmp4__length1;
#line 361 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		for (a_it = 0; a_it < _tmp4__length1; a_it = a_it + 1) {
#line 3212 "backend.c"
			gchar* _tmp5_ = NULL;
			gchar* a = NULL;
#line 361 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			_tmp5_ = g_strdup (a_collection[a_it]);
#line 361 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			a = _tmp5_;
#line 3219 "backend.c"
			{
				gchar** info = NULL;
				const gchar* _tmp6_ = NULL;
				gchar** _tmp7_ = NULL;
				gchar** _tmp8_ = NULL;
				gint info_length1 = 0;
				gint _info_size_ = 0;
				gchar* proto = NULL;
				gchar** _tmp9_ = NULL;
				gint _tmp9__length1 = 0;
				const gchar* _tmp10_ = NULL;
				gchar* _tmp11_ = NULL;
				gchar* addr = NULL;
				gchar** _tmp12_ = NULL;
				gint _tmp12__length1 = 0;
				const gchar* _tmp13_ = NULL;
				gchar* _tmp14_ = NULL;
				GeeHashMap* _tmp15_ = NULL;
				gchar* _tmp16_ = NULL;
				gchar* _tmp17_ = NULL;
				gchar* _tmp18_ = NULL;
				gchar* _tmp19_ = NULL;
#line 363 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp6_ = a;
#line 363 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp8_ = _tmp7_ = g_strsplit (_tmp6_, "#", 0);
#line 363 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				info = _tmp8_;
#line 363 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				info_length1 = _vala_array_length (_tmp7_);
#line 363 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_info_size_ = info_length1;
#line 364 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp9_ = info;
#line 364 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp9__length1 = info_length1;
#line 364 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp10_ = _tmp9_[0];
#line 364 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp11_ = g_strdup (_tmp10_);
#line 364 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				proto = _tmp11_;
#line 365 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp12_ = info;
#line 365 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp12__length1 = info_length1;
#line 365 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp13_ = _tmp12_[1];
#line 365 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp14_ = g_strdup (_tmp13_);
#line 365 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				addr = _tmp14_;
#line 367 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp15_ = ret;
#line 367 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp16_ = addr;
#line 367 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				addr = NULL;
#line 367 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp17_ = _tmp16_;
#line 367 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp18_ = proto;
#line 367 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				proto = NULL;
#line 367 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_tmp19_ = _tmp18_;
#line 367 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				gee_abstract_map_set ((GeeAbstractMap*) _tmp15_, _tmp17_, _tmp19_);
#line 367 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_g_free0 (_tmp19_);
#line 367 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_g_free0 (_tmp17_);
#line 361 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_g_free0 (addr);
#line 361 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_g_free0 (proto);
#line 361 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				info = (_vala_array_free (info, info_length1, (GDestroyNotify) g_free), NULL);
#line 361 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
				_g_free0 (a);
#line 3300 "backend.c"
			}
		}
	}
#line 370 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	result = ret;
#line 370 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	im_addrs = (_vala_array_free (im_addrs, im_addrs_length1, (GDestroyNotify) g_free), NULL);
#line 370 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return result;
#line 3310 "backend.c"
}


const gchar* eds_test_backend_get_address_book_uid (EdsTestBackend* self) {
	const gchar* result;
	EBookClient* _tmp0_ = NULL;
	ESource* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
#line 50 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 50 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp0_ = self->priv->_addressbook;
#line 50 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp1_ = e_client_get_source ((EClient*) _tmp0_);
#line 50 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_tmp2_ = e_source_get_uid (_tmp1_);
#line 50 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	result = _tmp2_;
#line 50 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return result;
#line 3331 "backend.c"
}


static void eds_test_value_backend_init (GValue* value) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	value->data[0].v_pointer = NULL;
#line 3338 "backend.c"
}


static void eds_test_value_backend_free_value (GValue* value) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (value->data[0].v_pointer) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		eds_test_backend_unref (value->data[0].v_pointer);
#line 3347 "backend.c"
	}
}


static void eds_test_value_backend_copy_value (const GValue* src_value, GValue* dest_value) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (src_value->data[0].v_pointer) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		dest_value->data[0].v_pointer = eds_test_backend_ref (src_value->data[0].v_pointer);
#line 3357 "backend.c"
	} else {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		dest_value->data[0].v_pointer = NULL;
#line 3361 "backend.c"
	}
}


static gpointer eds_test_value_backend_peek_pointer (const GValue* value) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return value->data[0].v_pointer;
#line 3369 "backend.c"
}


static gchar* eds_test_value_backend_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (collect_values[0].v_pointer) {
#line 3376 "backend.c"
		EdsTestBackend* object;
		object = collect_values[0].v_pointer;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		if (object->parent_instance.g_class == NULL) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 3383 "backend.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 3387 "backend.c"
		}
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		value->data[0].v_pointer = eds_test_backend_ref (object);
#line 3391 "backend.c"
	} else {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		value->data[0].v_pointer = NULL;
#line 3395 "backend.c"
	}
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return NULL;
#line 3399 "backend.c"
}


static gchar* eds_test_value_backend_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	EdsTestBackend** object_p;
	object_p = collect_values[0].v_pointer;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (!object_p) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 3410 "backend.c"
	}
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (!value->data[0].v_pointer) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		*object_p = NULL;
#line 3416 "backend.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		*object_p = value->data[0].v_pointer;
#line 3420 "backend.c"
	} else {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		*object_p = eds_test_backend_ref (value->data[0].v_pointer);
#line 3424 "backend.c"
	}
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return NULL;
#line 3428 "backend.c"
}


GParamSpec* eds_test_param_spec_backend (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	EdsTestParamSpecBackend* spec;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_val_if_fail (g_type_is_a (object_type, EDS_TEST_TYPE_BACKEND), NULL);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return G_PARAM_SPEC (spec);
#line 3442 "backend.c"
}


gpointer eds_test_value_get_backend (const GValue* value) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, EDS_TEST_TYPE_BACKEND), NULL);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return value->data[0].v_pointer;
#line 3451 "backend.c"
}


void eds_test_value_set_backend (GValue* value, gpointer v_object) {
	EdsTestBackend* old;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, EDS_TEST_TYPE_BACKEND));
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	old = value->data[0].v_pointer;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (v_object) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, EDS_TEST_TYPE_BACKEND));
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		value->data[0].v_pointer = v_object;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		eds_test_backend_ref (value->data[0].v_pointer);
#line 3471 "backend.c"
	} else {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		value->data[0].v_pointer = NULL;
#line 3475 "backend.c"
	}
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (old) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		eds_test_backend_unref (old);
#line 3481 "backend.c"
	}
}


void eds_test_value_take_backend (GValue* value, gpointer v_object) {
	EdsTestBackend* old;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, EDS_TEST_TYPE_BACKEND));
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	old = value->data[0].v_pointer;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (v_object) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, EDS_TEST_TYPE_BACKEND));
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		value->data[0].v_pointer = v_object;
#line 3500 "backend.c"
	} else {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		value->data[0].v_pointer = NULL;
#line 3504 "backend.c"
	}
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (old) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		eds_test_backend_unref (old);
#line 3510 "backend.c"
	}
}


static void eds_test_backend_class_init (EdsTestBackendClass * klass) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	eds_test_backend_parent_class = g_type_class_peek_parent (klass);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	EDS_TEST_BACKEND_CLASS (klass)->finalize = eds_test_backend_finalize;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_type_class_add_private (klass, sizeof (EdsTestBackendPrivate));
#line 3522 "backend.c"
}


static void eds_test_backend_instance_init (EdsTestBackend * self) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv = EDS_TEST_BACKEND_GET_PRIVATE (self);
#line 41 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_addressbook = NULL;
#line 44 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_source_registry = NULL;
#line 45 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_source = NULL;
#line 46 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_source_file = NULL;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->ref_count = 1;
#line 3539 "backend.c"
}


static void eds_test_backend_finalize (EdsTestBackend* obj) {
	EdsTestBackend * self;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, EDS_TEST_TYPE_BACKEND, EdsTestBackend);
#line 40 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_free0 (self->priv->_addressbook_name);
#line 41 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (self->priv->_addressbook);
#line 42 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	self->priv->_e_contacts = (_vala_array_free (self->priv->_e_contacts, self->priv->_e_contacts_length1, (GDestroyNotify) g_free), NULL);
#line 43 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	__g_list_free__g_object_unref0_0 (self->priv->_contacts);
#line 44 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (self->priv->_source_registry);
#line 45 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (self->priv->_source);
#line 46 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	_g_object_unref0 (self->priv->_source_file);
#line 3561 "backend.c"
}


GType eds_test_backend_get_type (void) {
	static volatile gsize eds_test_backend_type_id__volatile = 0;
	if (g_once_init_enter (&eds_test_backend_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { eds_test_value_backend_init, eds_test_value_backend_free_value, eds_test_value_backend_copy_value, eds_test_value_backend_peek_pointer, "p", eds_test_value_backend_collect_value, "p", eds_test_value_backend_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (EdsTestBackendClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) eds_test_backend_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (EdsTestBackend), 0, (GInstanceInitFunc) eds_test_backend_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType eds_test_backend_type_id;
		eds_test_backend_type_id = g_type_register_fundamental (g_type_fundamental_next (), "EdsTestBackend", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&eds_test_backend_type_id__volatile, eds_test_backend_type_id);
	}
	return eds_test_backend_type_id__volatile;
}


gpointer eds_test_backend_ref (gpointer instance) {
	EdsTestBackend* self;
	self = instance;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	g_atomic_int_inc (&self->ref_count);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	return instance;
#line 3586 "backend.c"
}


void eds_test_backend_unref (gpointer instance) {
	EdsTestBackend* self;
	self = instance;
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		EDS_TEST_BACKEND_GET_CLASS (self)->finalize (self);
#line 38 "/opt/gnome3/source/folks/tests/lib/eds/backend.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 3599 "backend.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



